#[non_exhaustive]pub enum Error {
BufferTooSmall,
InvalidCharacter {
character: char,
index: usize,
},
NonAsciiCharacter {
index: usize,
},
}Expand description
Errors that could occur when decoding a Base58 encoded string.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BufferTooSmall
The output buffer was too small to contain the entire input.
InvalidCharacter
The input contained a character that was not part of the current Base58 alphabet.
Fields
NonAsciiCharacter
The input contained a multi-byte (or non-utf8) character which is unsupported by this Base58 decoder.