Trait SyncClient

pub trait SyncClient {
Show 27 methods // Required methods fn send_and_confirm_message<T>( &self, keypairs: &T, message: Message, ) -> Result<Signature, TransportError> where T: Signers + ?Sized; fn send_and_confirm_instruction( &self, keypair: &Keypair, instruction: Instruction, ) -> Result<Signature, TransportError>; fn transfer_and_confirm( &self, lamports: u64, keypair: &Keypair, pubkey: &Pubkey, ) -> Result<Signature, TransportError>; fn get_account_data( &self, pubkey: &Pubkey, ) -> Result<Option<Vec<u8>>, TransportError>; fn get_account( &self, pubkey: &Pubkey, ) -> Result<Option<Account>, TransportError>; fn get_account_with_commitment( &self, pubkey: &Pubkey, commitment_config: CommitmentConfig, ) -> Result<Option<Account>, TransportError>; fn get_balance(&self, pubkey: &Pubkey) -> Result<u64, TransportError>; fn get_balance_with_commitment( &self, pubkey: &Pubkey, commitment_config: CommitmentConfig, ) -> Result<u64, TransportError>; fn get_minimum_balance_for_rent_exemption( &self, data_len: usize, ) -> Result<u64, TransportError>; fn get_recent_blockhash( &self, ) -> Result<(Hash, FeeCalculator), TransportError>; fn get_recent_blockhash_with_commitment( &self, commitment_config: CommitmentConfig, ) -> Result<(Hash, FeeCalculator, u64), TransportError>; fn get_fee_calculator_for_blockhash( &self, blockhash: &Hash, ) -> Result<Option<FeeCalculator>, TransportError>; fn get_fee_rate_governor(&self) -> Result<FeeRateGovernor, TransportError>; fn get_signature_status( &self, signature: &Signature, ) -> Result<Option<Result<(), TransactionError>>, TransportError>; fn get_signature_status_with_commitment( &self, signature: &Signature, commitment_config: CommitmentConfig, ) -> Result<Option<Result<(), TransactionError>>, TransportError>; fn get_slot(&self) -> Result<u64, TransportError>; fn get_slot_with_commitment( &self, commitment_config: CommitmentConfig, ) -> Result<u64, TransportError>; fn get_transaction_count(&self) -> Result<u64, TransportError>; fn get_transaction_count_with_commitment( &self, commitment_config: CommitmentConfig, ) -> Result<u64, TransportError>; fn get_epoch_info(&self) -> Result<EpochInfo, TransportError>; fn poll_for_signature_confirmation( &self, signature: &Signature, min_confirmed_blocks: usize, ) -> Result<usize, TransportError>; fn poll_for_signature( &self, signature: &Signature, ) -> Result<(), TransportError>; fn get_new_blockhash( &self, blockhash: &Hash, ) -> Result<(Hash, FeeCalculator), TransportError>; fn get_latest_blockhash(&self) -> Result<Hash, TransportError>; fn get_latest_blockhash_with_commitment( &self, commitment_config: CommitmentConfig, ) -> Result<(Hash, u64), TransportError>; fn is_blockhash_valid( &self, blockhash: &Hash, commitment: CommitmentConfig, ) -> Result<bool, TransportError>; fn get_fee_for_message( &self, message: &Message, ) -> Result<u64, TransportError>;
}

Required Methods

fn send_and_confirm_message<T>( &self, keypairs: &T, message: Message, ) -> Result<Signature, TransportError>
where T: Signers + ?Sized,

Create a transaction from the given message, and send it to the server, retrying as-needed.

fn send_and_confirm_instruction( &self, keypair: &Keypair, instruction: Instruction, ) -> Result<Signature, TransportError>

Create a transaction from a single instruction that only requires a single signer. Then send it to the server, retrying as-needed.

fn transfer_and_confirm( &self, lamports: u64, keypair: &Keypair, pubkey: &Pubkey, ) -> Result<Signature, TransportError>

Transfer lamports from keypair to pubkey, retrying until the transfer completes or produces and error.

fn get_account_data( &self, pubkey: &Pubkey, ) -> Result<Option<Vec<u8>>, TransportError>

Get an account or None if not found.

fn get_account( &self, pubkey: &Pubkey, ) -> Result<Option<Account>, TransportError>

Get an account or None if not found.

fn get_account_with_commitment( &self, pubkey: &Pubkey, commitment_config: CommitmentConfig, ) -> Result<Option<Account>, TransportError>

Get an account or None if not found. Uses explicit commitment configuration.

fn get_balance(&self, pubkey: &Pubkey) -> Result<u64, TransportError>

Get account balance or 0 if not found.

fn get_balance_with_commitment( &self, pubkey: &Pubkey, commitment_config: CommitmentConfig, ) -> Result<u64, TransportError>

Get account balance or 0 if not found. Uses explicit commitment configuration.

fn get_minimum_balance_for_rent_exemption( &self, data_len: usize, ) -> Result<u64, TransportError>

fn get_recent_blockhash(&self) -> Result<(Hash, FeeCalculator), TransportError>

๐Ÿ‘ŽDeprecated since 1.9.0: Please use get_latest_blockhash instead

Get recent blockhash

fn get_recent_blockhash_with_commitment( &self, commitment_config: CommitmentConfig, ) -> Result<(Hash, FeeCalculator, u64), TransportError>

๐Ÿ‘ŽDeprecated since 1.9.0: Please use get_latest_blockhash_with_commitment and get_latest_blockhash_with_commitment instead

Get recent blockhash. Uses explicit commitment configuration.

fn get_fee_calculator_for_blockhash( &self, blockhash: &Hash, ) -> Result<Option<FeeCalculator>, TransportError>

๐Ÿ‘ŽDeprecated since 1.9.0: Please use get_fee_for_message or is_blockhash_valid instead

Get Some(FeeCalculator) associated with blockhash if it is still in the BlockhashQueue, otherwise None`

fn get_fee_rate_governor(&self) -> Result<FeeRateGovernor, TransportError>

๐Ÿ‘ŽDeprecated since 1.9.0: Please do not use, will no longer be available in the future

Get recent fee rate governor

fn get_signature_status( &self, signature: &Signature, ) -> Result<Option<Result<(), TransactionError>>, TransportError>

Get signature status.

fn get_signature_status_with_commitment( &self, signature: &Signature, commitment_config: CommitmentConfig, ) -> Result<Option<Result<(), TransactionError>>, TransportError>

Get signature status. Uses explicit commitment configuration.

fn get_slot(&self) -> Result<u64, TransportError>

Get last known slot

fn get_slot_with_commitment( &self, commitment_config: CommitmentConfig, ) -> Result<u64, TransportError>

Get last known slot. Uses explicit commitment configuration.

fn get_transaction_count(&self) -> Result<u64, TransportError>

Get transaction count

fn get_transaction_count_with_commitment( &self, commitment_config: CommitmentConfig, ) -> Result<u64, TransportError>

Get transaction count. Uses explicit commitment configuration.

fn get_epoch_info(&self) -> Result<EpochInfo, TransportError>

fn poll_for_signature_confirmation( &self, signature: &Signature, min_confirmed_blocks: usize, ) -> Result<usize, TransportError>

Poll until the signature has been confirmed by at least min_confirmed_blocks

fn poll_for_signature( &self, signature: &Signature, ) -> Result<(), TransportError>

Poll to confirm a transaction.

fn get_new_blockhash( &self, blockhash: &Hash, ) -> Result<(Hash, FeeCalculator), TransportError>

๐Ÿ‘ŽDeprecated since 1.9.0: Please do not use, will no longer be available in the future
fn get_latest_blockhash(&self) -> Result<Hash, TransportError>

Get last known blockhash

fn get_latest_blockhash_with_commitment( &self, commitment_config: CommitmentConfig, ) -> Result<(Hash, u64), TransportError>

Get latest blockhash with last valid block height. Uses explicit commitment configuration.

fn is_blockhash_valid( &self, blockhash: &Hash, commitment: CommitmentConfig, ) -> Result<bool, TransportError>

Check if the blockhash is valid

fn get_fee_for_message(&self, message: &Message) -> Result<u64, TransportError>

Calculate the fee for a Message

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors