Struct AccountMeta

#[repr(C)]
pub struct AccountMeta { pub pubkey: Pubkey, pub is_signer: bool, pub is_writable: bool, }
Describes a single account read or written by a program during instruction execution.

When constructing an Instruction, a list of all accounts that may be read or written during the execution of that instruction must be supplied. Any account that may be mutated by the program during execution, either its data or metadata such as held lamports, must be writable.

Note that because the Solana runtime schedules parallel transaction execution around which accounts are writable, care should be taken that only accounts which actually may be mutated are specified as writable. As the default AccountMeta::new constructor creates writable accounts, this is a minor hazard: use AccountMeta::new_readonly to specify that an account is not writable.

Fields

pubkey: Pubkey

An accountโ€™s public key.

is_signer: bool

True if an Instruction requires a Transaction signature matching pubkey.

is_writable: bool

True if the account data or metadata may be mutated during program execution.

Implementations

Source

impl AccountMeta

pub fn new(pubkey: Pubkey, is_signer: bool) -> AccountMeta

Construct metadata for a writable account.

Examples
let instr = Instruction::new_with_borsh(
    program_id,
    &instruction,
    vec![
        AccountMeta::new(from, true),
        AccountMeta::new(to, false),
    ],
);
pub fn new_readonly(pubkey: Pubkey, is_signer: bool) -> AccountMeta

Construct metadata for a read-only account.

Examples
let instr = Instruction::new_with_borsh(
    program_id,
    &instruction,
    vec![
        AccountMeta::new(from, true),
        AccountMeta::new(to, false),
        AccountMeta::new_readonly(from_account_storage, false),
    ],
);