#[repr(C)]pub struct LoaderV4State {
pub slot: u64,
pub authority_address: Pubkey,
pub status: LoaderV4Status,
}Expand description
LoaderV4 account states
Fields
slot: u64Slot in which the program was last deployed, retracted or initialized.
Address of signer which can send program management instructions.
status: LoaderV4StatusDeployment status.
Implementations
Sourceimpl LoaderV4State
impl LoaderV4State
Sourcepub const fn program_data_offset() -> usize
pub const fn program_data_offset() -> usize
Size of a serialized program account.