Enum VersionedMessage

pub enum VersionedMessage {
    Legacy(Message),
    V0(Message),
}
Either a legacy message or a v0 message.

Serialization

If the first bit is set, the remaining 7 bits will be used to determine which message version is serialized starting from version 0. If the first is bit is not set, all bytes are used to encode the legacy Message format.

Variants

Implementations

Source

impl VersionedMessage

pub fn sanitize(&self) -> Result<(), SanitizeError>

pub fn header(&self) -> &MessageHeader

pub fn static_account_keys(&self) -> &[Pubkey]

pub fn address_table_lookups(&self) -> Option<&[MessageAddressTableLookup]>

pub fn is_signer(&self, index: usize) -> bool

Returns true if the account at the specified index signed this message.

pub fn is_maybe_writable(&self, index: usize) -> bool

Returns true if the account at the specified index is writable by the instructions in this message. Since dynamically loaded addresses canโ€™t have write locks demoted without loading addresses, this shouldnโ€™t be used in the runtime.

pub fn is_invoked(&self, key_index: usize) -> bool

pub fn is_non_loader_key(&self, key_index: usize) -> bool

Returns true if the account at the specified index is not invoked as a program or, if invoked, is passed to a program.

pub fn recent_blockhash(&self) -> &Hash

pub fn set_recent_blockhash(&mut self, recent_blockhash: Hash)

pub fn instructions(&self) -> &[CompiledInstruction]

Program instructions that will be executed in sequence and committed in one atomic transaction if all succeed.

pub fn serialize(&self) -> Vec<u8> โ“˜

pub fn hash(&self) -> Hash

Compute the blake3 hash of this transactionโ€™s message

pub fn hash_raw_message(message_bytes: &[u8]) -> Hash

Compute the blake3 hash of a raw transaction message