Struct AccountKeys

pub struct AccountKeys<'a> { /* private fields */ }
Collection of static and dynamically loaded keys used to load accounts during transaction processing.

Implementations

Source

impl<'a> AccountKeys<'a>

pub fn new( static_keys: &'a [Pubkey], dynamic_keys: Option<&'a LoadedAddresses>, ) -> AccountKeys<'a>

pub fn get(&self, index: usize) -> Option<&'a Pubkey>

Returns the address of the account at the specified index of the list of message account keys constructed from static keys, followed by dynamically loaded writable addresses, and lastly the list of dynamically loaded readonly addresses.

pub fn len(&self) -> usize

Returns the total length of loaded accounts for a message

pub fn is_empty(&self) -> bool

Returns true if this collection of account keys is empty

pub fn iter(&self) -> impl Iterator<Item = &'a Pubkey>

Iterator for the addresses of the loaded accounts for a message

pub fn compile_instructions( &self, instructions: &[Instruction], ) -> Vec<CompiledInstruction>

Compile instructions using the order of account keys to determine compiled instruction account indexes.

Panics

Panics when compiling fails. See AccountKeys::try_compile_instructions for a full description of failure scenarios.

pub fn try_compile_instructions( &self, instructions: &[Instruction], ) -> Result<Vec<CompiledInstruction>, CompileError>

Compile instructions using the order of account keys to determine compiled instruction account indexes.

Errors

Compilation will fail if any instructions use account keys which are not present in this account key collection.

Compilation will fail if any instructions use account keys which are located at an index which cannot be cast to a u8 without overflow.