Struct LegacyMessage

pub struct LegacyMessage<'a> {
    pub message: Cow<'a, Message>,
    pub is_writable_account_cache: Vec<bool>,
}

Fields

message: Cow<'a, Message>

Legacy message

is_writable_account_cache: Vec<bool>

List of boolean with same length as account_keys(), each boolean value indicates if corresponding account key is writable or not.

Implementations

Source

impl<'a> LegacyMessage<'a>

pub fn new(message: Message) -> LegacyMessage<'a>

pub fn has_duplicates(&self) -> bool

pub fn is_key_called_as_program(&self, key_index: usize) -> bool

pub fn is_upgradeable_loader_present(&self) -> bool

Inspect all message keys for the bpf upgradeable loader

pub fn account_keys(&self) -> AccountKeys<'_>

Returns the full list of account keys.

pub fn is_writable(&self, index: usize) -> bool