pub struct SanitizedVersionedMessage {
pub message: VersionedMessage,
}Expand description
Wraps a sanitized VersionedMessage to provide a safe API
Fields
message: VersionedMessageImplementations
Sourceimpl SanitizedVersionedMessage
impl SanitizedVersionedMessage
pub fn try_new( message: VersionedMessage, ) -> Result<SanitizedVersionedMessage, SanitizeError>
Sourcepub fn instructions(&self) -> &[CompiledInstruction]
pub fn instructions(&self) -> &[CompiledInstruction]
Program instructions that will be executed in sequence and committed in one atomic transaction if all succeed.
Sourcepub fn program_instructions_iter(
&self,
) -> impl Iterator<Item = (&Pubkey, &CompiledInstruction)>
pub fn program_instructions_iter( &self, ) -> impl Iterator<Item = (&Pubkey, &CompiledInstruction)>
Program instructions iterator which includes each instructionโs program id.