pub struct LoadedMessage<'a> {
pub message: Cow<'a, Message>,
pub loaded_addresses: Cow<'a, LoadedAddresses>,
pub is_writable_account_cache: Vec<bool>,
}Expand description
Combination of a version #0 message and its loaded addresses
Fields
message: Cow<'a, Message>Message which loaded a collection of lookup table addresses
loaded_addresses: Cow<'a, LoadedAddresses>Addresses loaded with on-chain address lookup tables
is_writable_account_cache: Vec<bool>List of boolean with same length as account_keys(), each boolean value indicates if corresponding account key is writable or not.
Implementations
Sourceimpl<'a> LoadedMessage<'a>
impl<'a> LoadedMessage<'a>
pub fn new( message: Message, loaded_addresses: LoadedAddresses, ) -> LoadedMessage<'a>
pub fn new_borrowed( message: &'a Message, loaded_addresses: &'a LoadedAddresses, ) -> LoadedMessage<'a>
Sourcepub fn account_keys(&self) -> AccountKeys<'_>
pub fn account_keys(&self) -> AccountKeys<'_>
Returns the full list of static and dynamic account keys that are loaded for this message.
Sourcepub fn static_account_keys(&self) -> &[Pubkey]
pub fn static_account_keys(&self) -> &[Pubkey]
Returns the list of static account keys that are loaded for this message.
Sourcepub fn has_duplicates(&self) -> bool
pub fn has_duplicates(&self) -> bool
Returns true if any account keys are duplicates
pub fn is_writable(&self, key_index: usize) -> bool
pub fn is_signer(&self, i: usize) -> bool
pub fn demote_program_id(&self, i: usize) -> bool
Sourcepub fn is_key_called_as_program(&self, key_index: usize) -> bool
pub fn is_key_called_as_program(&self, key_index: usize) -> bool
Returns true if the account at the specified index is called as a program by an instruction
Sourcepub fn is_upgradeable_loader_present(&self) -> bool
pub fn is_upgradeable_loader_present(&self) -> bool
Returns true if any account is the bpf upgradeable loader