pub struct MessageAddressTableLookup {
pub account_key: Pubkey,
pub writable_indexes: Vec<u8>,
pub readonly_indexes: Vec<u8>,
}Expand description
Address table lookups describe an on-chain address lookup table to use for loading more readonly and writable accounts in a single tx.
Fields
account_key: PubkeyAddress lookup table account key
writable_indexes: Vec<u8>List of indexes used to load writable account addresses
readonly_indexes: Vec<u8>List of indexes used to load readonly account addresses