pub struct Data {
pub authority: Pubkey,
pub durable_nonce: DurableNonce,
pub fee_calculator: FeeCalculator,
}Expand description
Initialized data of a durable transaction nonce account.
This is stored within State for initialized nonce accounts.
Fields
Address of the account that signs transactions using the nonce account.
durable_nonce: DurableNonceDurable nonce value derived from a valid previous blockhash.
fee_calculator: FeeCalculatorThe fee calculator associated with the blockhash.
Implementations
Sourceimpl Data
impl Data
Sourcepub fn new(
authority: Pubkey,
durable_nonce: DurableNonce,
lamports_per_signature: u64,
) -> Data
pub fn new( authority: Pubkey, durable_nonce: DurableNonce, lamports_per_signature: u64, ) -> Data
Create new durable transaction nonce data.
Sourcepub fn blockhash(&self) -> Hash
pub fn blockhash(&self) -> Hash
Hash value used as recent_blockhash field in Transactions. Named blockhash for legacy reasons, but durable nonce and blockhash have separate domains.
Sourcepub fn get_lamports_per_signature(&self) -> u64
pub fn get_lamports_per_signature(&self) -> u64
Get the cost per signature for the next transaction to use this nonce.