Struct Lockup

pub struct Lockup {
    pub unix_timestamp: i64,
    pub epoch: u64,
    pub custodian: Pubkey,
}

Fields

unix_timestamp: i64

UnixTimestamp at which this stake will allow withdrawal, unless the transaction is signed by the custodian

epoch: u64

epoch height at which this stake will allow withdrawal, unless the transaction is signed by the custodian

custodian: Pubkey

custodian signature on a transaction exempts the operation from lockup constraints

Implementations

Source

impl Lockup

pub fn is_in_force(&self, clock: &Clock, custodian: Option<&Pubkey>) -> bool