Struct Instructions

pub struct Instructions();
Instructions sysvar, dummy type.

This type exists for consistency with other sysvar modules, but is a dummy type that does not contain sysvar data. It implements the SysvarId trait but does not implement the Sysvar trait.

Use the free functions in this module to access the instructions sysvar.