pub struct IterItem<'a>(pub u64, pub &'a Hash, pub u64);๐Deprecated since 1.9.0: Please do not use, will no longer be available in the future
Tuple Fields
0: u64๐Deprecated since 1.9.0: Please do not use, will no longer be available in the future
1: &'a Hash๐Deprecated since 1.9.0: Please do not use, will no longer be available in the future
2: u64๐Deprecated since 1.9.0: Please do not use, will no longer be available in the future