pub struct AtomicInterval { /* private fields */ }Implementations
Sourceimpl AtomicInterval
impl AtomicInterval
Sourcepub fn should_update(&self, interval_time_ms: u64) -> bool
pub fn should_update(&self, interval_time_ms: u64) -> bool
true if โinterval_time_msโ has elapsed since last time we returned true as long as it has been โinterval_time_msโ since this struct was created
Sourcepub fn should_update_ext(&self, interval_time_ms: u64, skip_first: bool) -> bool
pub fn should_update_ext(&self, interval_time_ms: u64, skip_first: bool) -> bool
a primary use case is periodic metric reporting, potentially from different threads true if โinterval_time_msโ has elapsed since last time we returned true except, if skip_first=false, false until โinterval_time_msโ has elapsed since this struct was created
Sourcepub fn elapsed_ms(&self) -> u64
pub fn elapsed_ms(&self) -> u64
return ms elapsed since the last time the time was set
Sourcepub fn remaining_until_next_interval(&self, interval_time: u64) -> u64
pub fn remaining_until_next_interval(&self, interval_time: u64) -> u64
return ms until the interval_time will have elapsed