pub struct VersionedTransaction {
pub signatures: Vec<Signature>,
pub message: VersionedMessage,
}Expand description
An atomic transaction
Fields
signatures: Vec<Signature>List of signatures
message: VersionedMessageMessage to sign.
Implementations
Sourceimpl VersionedTransaction
impl VersionedTransaction
Sourcepub fn try_new<T>(
message: VersionedMessage,
keypairs: &T,
) -> Result<VersionedTransaction, SignerError>
pub fn try_new<T>( message: VersionedMessage, keypairs: &T, ) -> Result<VersionedTransaction, SignerError>
Signs a versioned message and if successful, returns a signed transaction.
pub fn sanitize(&self) -> Result<(), SanitizeError>
Sourcepub fn version(&self) -> TransactionVersion
pub fn version(&self) -> TransactionVersion
Returns the version of the transaction
Sourcepub fn into_legacy_transaction(self) -> Option<Transaction>
pub fn into_legacy_transaction(self) -> Option<Transaction>
Returns a legacy transaction if the transaction message is legacy.
Sourcepub fn verify_and_hash_message(&self) -> Result<Hash, TransactionError>
pub fn verify_and_hash_message(&self) -> Result<Hash, TransactionError>
Verify the transaction and hash its message
Sourcepub fn verify_with_results(&self) -> Vec<bool>
pub fn verify_with_results(&self) -> Vec<bool>
Verify the transaction and return a list of verification results
Sourcepub fn uses_durable_nonce(&self) -> bool
pub fn uses_durable_nonce(&self) -> bool
Returns true if transaction begins with a valid advance nonce instruction. Since dynamically loaded addresses canโt have write locks demoted without loading addresses, this shouldnโt be used in the runtime.