pub struct ExecutionRecord {
pub accounts: Vec<(Pubkey, AccountSharedData)>,
pub return_data: TransactionReturnData,
pub touched_account_count: u64,
pub accounts_resize_delta: i64,
}Expand description
Everything that needs to be recorded from a TransactionContext after execution
Fields
accounts: Vec<(Pubkey, AccountSharedData)>return_data: TransactionReturnDatatouched_account_count: u64accounts_resize_delta: i64Trait Implementations
Sourceimpl From<TransactionContext> for ExecutionRecord
Used by the bank in the runtime to write back the processed accounts and recorded instructions
impl From<TransactionContext> for ExecutionRecord
Used by the bank in the runtime to write back the processed accounts and recorded instructions
Sourcefn from(context: TransactionContext) -> ExecutionRecord
fn from(context: TransactionContext) -> ExecutionRecord
Converts to this type from the input type.