#[repr(C)]pub struct Clock {
pub slot: u64,
pub epoch_start_timestamp: i64,
pub epoch: u64,
pub leader_schedule_epoch: u64,
pub unix_timestamp: i64,
}Expand description
A representation of network time.
All members of Clock start from 0 upon network boot.
Fields
slot: u64The current Slot.
epoch_start_timestamp: i64The timestamp of the first Slot in this Epoch.
epoch: u64The current Epoch.
leader_schedule_epoch: u64The future Epoch for which the leader schedule has
most recently been calculated.
unix_timestamp: i64The approximate real world time of the current slot.
This value was originally computed from genesis creation time and
network time in slots, incurring a lot of drift. Following activation of
the timestamp_correction and timestamp_bounding features it
is calculated using a validator timestamp oracle.