#[repr(C)]pub struct AccountMeta {
pub pubkey: Pubkey,
pub is_signer: bool,
pub is_writable: bool,
}Expand description
Describes a single account read or written by a program during instruction execution.
When constructing an Instruction, a list of all accounts that may be
read or written during the execution of that instruction must be supplied.
Any account that may be mutated by the program during execution, either its
data or metadata such as held lamports, must be writable.
Note that because the Solana runtime schedules parallel transaction
execution around which accounts are writable, care should be taken that only
accounts which actually may be mutated are specified as writable. As the
default AccountMeta::new constructor creates writable accounts, this is
a minor hazard: use AccountMeta::new_readonly to specify that an account
is not writable.
Fields
pubkey: PubkeyAn accountโs public key.
is_signer: boolTrue if an Instruction requires a Transaction signature matching pubkey.
is_writable: boolTrue if the account data or metadata may be mutated during program execution.
Implementations
Sourceimpl AccountMeta
impl AccountMeta
Sourcepub fn new(pubkey: Pubkey, is_signer: bool) -> AccountMeta
pub fn new(pubkey: Pubkey, is_signer: bool) -> AccountMeta
Construct metadata for a writable account.
Examples
let instr = Instruction::new_with_borsh(
program_id,
&instruction,
vec![
AccountMeta::new(from, true),
AccountMeta::new(to, false),
],
);Sourcepub fn new_readonly(pubkey: Pubkey, is_signer: bool) -> AccountMeta
pub fn new_readonly(pubkey: Pubkey, is_signer: bool) -> AccountMeta
Construct metadata for a read-only account.
Examples
let instr = Instruction::new_with_borsh(
program_id,
&instruction,
vec![
AccountMeta::new(from, true),
AccountMeta::new(to, false),
AccountMeta::new_readonly(from_account_storage, false),
],
);Trait Implementations
Sourceimpl Clone for AccountMeta
impl Clone for AccountMeta
Sourcefn clone(&self) -> AccountMeta
fn clone(&self) -> AccountMeta
1.0.0 ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AccountMeta
impl Debug for AccountMeta
Sourceimpl Default for AccountMeta
impl Default for AccountMeta
Sourcefn default() -> AccountMeta
fn default() -> AccountMeta
Sourceimpl<'de> Deserialize<'de> for AccountMeta
impl<'de> Deserialize<'de> for AccountMeta
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<AccountMeta, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<AccountMeta, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for AccountMeta
impl PartialEq for AccountMeta
Sourceimpl Serialize for AccountMeta
impl Serialize for AccountMeta
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl Eq for AccountMeta
impl StructuralPartialEq for AccountMeta