pub struct CompiledInstruction {
pub program_id_index: u8,
pub accounts: Vec<u8>,
pub data: Vec<u8>,
}Expand description
A compact encoding of an instruction.
A CompiledInstruction is a component of a multi-instruction Message,
which is the core of a Solana transaction. It is created during the
construction of Message. Most users will not interact with it directly.
Fields
program_id_index: u8Index into the transaction keys array indicating the program account that executes this instruction.
accounts: Vec<u8>Ordered indices into the transaction keys array indicating which accounts to pass to the program.
data: Vec<u8>The program input data.
Implementations
Sourceimpl CompiledInstruction
impl CompiledInstruction
pub fn new<T>(
program_ids_index: u8,
data: &T,
accounts: Vec<u8>,
) -> CompiledInstructionwhere
T: Serialize,
pub fn new_from_raw_parts( program_id_index: u8, data: Vec<u8>, accounts: Vec<u8>, ) -> CompiledInstruction
pub fn program_id<'a>(&self, program_ids: &'a [Pubkey]) -> &'a Pubkey