Enum AddressLoaderError

pub enum AddressLoaderError {
    Disabled,
    SlotHashesSysvarNotFound,
    LookupTableAccountNotFound,
    InvalidAccountOwner,
    InvalidAccountData,
    InvalidLookupIndex,
}

Variants



Disabled

Address loading from lookup tables is disabled



SlotHashesSysvarNotFound

Failed to load slot hashes sysvar



LookupTableAccountNotFound

Attempted to lookup addresses from a table that does not exist



InvalidAccountOwner

Attempted to lookup addresses from an account owned by the wrong program



InvalidAccountData

Attempted to lookup addresses from an invalid account



InvalidLookupIndex

Address lookup contains an invalid index