pub struct ShortU16(pub u16);Expand description
Same as u16, but serialized with 1 to 3 bytes. If the value is above 0x7f, the top bit is set and the remaining value is stored in the next bytes. Each byte follows the same pattern until the 3rd byte. The 3rd byte, if needed, uses all 8 bits to store the last byte of the original value.
Tuple Fields
0: u16Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ShortU16
impl<'de> Deserialize<'de> for ShortU16
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<ShortU16, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<ShortU16, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for ShortU16
impl Serialize for ShortU16
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more